@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12831 2021-04-04 03:45:08Z Becca $
+# $Id: cms_plugins.py 12837 2021-04-08 06:32:21Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Becca $ (last)
-# $Date: 2021-04-04 11:45:08 +0800 (Sun, 04 Apr 2021) $
-# $Revision: 12831 $
+# $Date: 2021-04-08 14:32:21 +0800 (Thu, 08 Apr 2021) $
+# $Revision: 12837 $
 
 from django.db.models import Count
 from django.template.loader import select_template
@@ -39,20 +39,10 @@ if hasattr(Product, 'tags'):
 else:
     hasTags = False
 
-class FeaturedPlugin(CMSPluginBase):
-    model = OscarFeatured
-    module = "Shop"
-    name = "Featured Products"
-    render_template = settings.ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE
-    form = OscarFeaturedForm
 
-    def get_render_template(self, context, instance, placeholder):
-        return select_template([
-            instance.renderTemplate,
-            settings.ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE,
-        ])
-
-    def render(self, context, instance, placeholder):
+class BasePlugin(CMSPluginBase):
+    
+    def render(self, context, instance, placeholder, orderBy):
         catagories = instance.catagory.all()
         query = None
 
@@ -91,9 +81,9 @@ class FeaturedPlugin(CMSPluginBase):
 
         if queryset.count() >= instance.limit:
             topViewProducts = \
-                queryset.order_by('-num_views')[:instance.limit]
+                queryset.order_by(orderBy)[:instance.limit]
         else:
-            topViewProducts = queryset.order_by('-num_views')
+            topViewProducts = queryset.order_by(orderBy)
         products = [x.product for x in topViewProducts]
         context.update({
             'products': products,
@@ -101,6 +91,40 @@ class FeaturedPlugin(CMSPluginBase):
 
         return context
 
+class BestSellerPlugin(BasePlugin):
+    model = OscarBestSeller
+    module = "Shop"
+    name = "Bestseller Products"
+    render_template = settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE
+    form = OscarBestSellerForm
+
+    def get_render_template(self, context, instance, placeholder):
+        return select_template([
+            instance.renderTemplate,
+            settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE,
+        ])
+
+    def render(self, context, instance, placeholder):
+        return super().render(context, instance, placeholder, '-num_purchases')
+
+class FeaturedPlugin(BasePlugin):
+    model = OscarFeatured
+    module = "Shop"
+    name = "Featured Products"
+    render_template = settings.ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE
+    form = OscarFeaturedForm
+
+    def get_render_template(self, context, instance, placeholder):
+        return select_template([
+            instance.renderTemplate,
+            settings.ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE,
+        ])
+
+
+    def render(self, context, instance, placeholder):
+        return super().render(context, instance, placeholder, '-num_views')
+
+
 class LatestPlugin(CMSPluginBase):
     model = OscarLatest
     module = "Shop"
@@ -161,67 +185,7 @@ class LatestPlugin(CMSPluginBase):
 
         return context
 
-class BestSellerPlugin(CMSPluginBase):
-    model = OscarBestSeller
-    module = "Shop"
-    name = "Bestseller Products"
-    render_template = settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE
-    form = OscarBestSellerForm
 
-    def get_render_template(self, context, instance, placeholder):
-        return select_template([
-            instance.renderTemplate,
-            settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE,
-        ])
-
-    def render(self, context, instance, placeholder):
-        catagories = instance.catagory.all()
-        query = None
-
-        # category
-        if catagories:
-            for c in catagories:
-                if query:
-                    if instance.filterMethod == OR:
-                        query = query | Q(product__categories__id=c.id)
-                    else:
-                        query = query & Q(product__categories__id=c.id)
-                else:
-                    query = Q(product__categories__id=c.id)
-
-        # tag
-        if hasTags:
-            if instance.tag:
-                tags = [int(t) for t in instance.tag.split(",")]
-            else:
-                tags = []
-
-            if tags:
-                for t in tags:
-                    if query:
-                        if instance.filterMethod == OR:
-                            query = query | Q(product__tags__id=t)
-                        else:
-                            query = query & Q(product__tags__id=t)
-                    else:
-                        query = Q(product__tags__id=t)
-
-        if query:
-            queryset = ProductRecord.objects.filter(query)
-        else:
-            queryset = ProductRecord.objects.all()
-
-        if queryset.count() >= instance.limit:
-            bestSeller = \
-                queryset.order_by('-num_purchases')[:instance.limit]
-        else:
-            bestSeller = queryset.order_by('-num_purchases')
-        products = [x.product for x in bestSeller]
-        context.update({
-            'products': products,
-        })
-
-        return context
 
 
 class OfferPlugin(CMSPluginBase):
