@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12209 2020-05-13 07:27:11Z Lavender $
+# $Id: cms_plugins.py 13272 2021-08-24 05:47:26Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-05-13 15:27:11 +0800 (Wed, 13 May 2020) $
-# $Revision: 12209 $
+# $Author: Casey $
+# $Date: 2021-08-24 13:47:26 +0800 (Tue, 24 Aug 2021) $
+# $Revision: 13272 $
 
 import re
 import requests
@@ -105,7 +105,7 @@ def getFanPageId(accessToken, url):
     req = requests.get(
         ("https://graph.facebook.com/v6.0/%s?access_token=%s&debug=all"
          "&format=json&method=get&pretty=0&suppress_http_code=1") % (
-         fanPageUrl, accessToken))
+         fanPageUrl, accessToken), proxies=zephyrusSettings.ZEPHYRUS_FACEBOOK_PROXY)
     text = req.text
 
     data = json.loads(text)
@@ -119,7 +119,8 @@ def getFanPageId(accessToken, url):
 def getFanPage(url, limit):
     try:
         # get data
-        req = requests.get("%sposts/?ref=page_internal&_fb_noscript=1" % url)  
+        req = requests.get(
+            "%sposts/?ref=page_internal&_fb_noscript=1" % url, proxies=zephyrusSettings.ZEPHYRUS_FACEBOOK_PROXY)  
         content = req.text
         soup = BeautifulSoup(content, 'html.parser')
         
@@ -178,6 +179,7 @@ def getFanPage(url, limit):
         return fpList
     except Exception as e:
         logger.error(str(e))
+        raise
         return [] # no post
 
 class FacebookFanPlugin(CMSPluginBase):
@@ -334,7 +336,7 @@ class FacebookFanPlugin(CMSPluginBase):
 def getFanPhoto(url, limit):
     try:
         # get data
-        req = requests.get(url)  
+        req = requests.get(url, proxies=zephyrusSettings.ZEPHYRUS_FACEBOOK_PROXY)  
         content = req.text
         startStr = '''"media":{"edges":['''
         endStr = '''],"page_info":'''
@@ -365,6 +367,7 @@ def getFanPhoto(url, limit):
         return photoList
     except Exception as e:
         logger.error(str(e))
+        raise
         return [] # no photo
         
 class FacebookPhotoPlugin(CMSPluginBase):
@@ -412,6 +415,9 @@ class FacebookPhotoPlugin(CMSPluginBase):
             if 'album_id=' in instance.url:
                 index = instance.url.index('album_id=') + len('album_id=')
                 albumId = instance.url[index:]
+            elif 'set=' in instance.url:
+                index = instance.url.index('set=') + len('set=')
+                albumId = str(instance.url[index:]).strip('a.')
             else:
                 if not fanPageId:
                     
